check_var — skchange

Skip to main content
`Ctrl`+`K`

# check_var

check_var(var: Buffer | _SupportsArray[dtype[Any]] | _NestedSequence[_SupportsArray[dtype[Any]]] | bool | int | float | complex | str | bytes | _NestedSequence[bool | int | float | complex | str | bytes] | Number, X: ndarray) → ndarray

  Check if the fixed variance parameter is valid.

  Parameters:
    varnp.ndarray or numbers.Number

      Fixed variance for the cost calculation.

    Xnp.ndarray

      2d input data.

  Returns:
    varnp.ndarray

      Fixed variance for the cost calculation.